==> lxqt-notificationd_0.16.0.orig.tar.xz: lxqt-notificationd-0.16.0/config/translations/lxqt-config-notificationd_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>Razmaci:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Neke obavijesti postavljaju vlastita trajanja prikaza.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>Standardno trajanje:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Nepročitane obavijesti</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Broj spremljenih obavijesti:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>Ime programa se nalazi pri vrhu obavijesti.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Zanemari ove programe:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>program1,program2,program3</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>Veličine</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Osnovne postavke</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Položaj na ekranu</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="61"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="70"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Nijedan demon za obavijesti nije pokrenut.
Koristit će se rezervni.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="73"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Pokrenut je jedan strani demon za obavijesti (%1).
Ove postavke na njega ne utječu!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="131"/>
        <source>Notification demo </source>
        <translation>Demonstracija obavijesti </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="132"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Ovo je testna obavijest.
Sve obavijesti će se sada ovdje pojaviti na LXQt-u.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Obavijesti radne površine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Osnovne postavke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Napredne postavke</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_0.17.0.orig.tar.xz: lxqt-notificationd-0.17.0/config/translations/lxqt-config-notificationd_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="75"/>
        <source>Width:</source>
        <translation>Širina:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source>Spacing:</source>
        <translation>Razmaci:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="118"/>
        <source>Duration</source>
        <translation>Trajanje</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="130"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Neke obavijesti postavljaju vlastita trajanja prikaza.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="142"/>
        <source>Default duration:</source>
        <translation>Standardno trajanje:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <source> sec</source>
        <translation> s</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Unattended Notifications</source>
        <translation>Nepročitane obavijesti</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>How many to save:</source>
        <translation>Broj spremljenih obavijesti:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="39"/>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Application name is on the top of notification.</source>
        <translation>Ime programa se nalazi pri vrhu obavijesti.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="42"/>
        <source>Ignore these applications:</source>
        <translation>Zanemari ove programe:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="52"/>
        <source>app1,app2,app3</source>
        <translation>program1,program2,program3</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="67"/>
        <source>Sizes</source>
        <translation>Veličine</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="82"/>
        <location filename="../advancedsettings.ui" line="106"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="177"/>
        <source>Screen</source>
        <translation>Ekran</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="183"/>
        <source>When unchecked the notification will always show on primary screen</source>
        <translation>Kad nije označeno, obavijest će se uvijek prikazati na primarnom ekranu</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="186"/>
        <source>Show notifications on screen with the mouse</source>
        <translation>Prikaži obavijesti na ekranu s mišem</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Osnovne postavke</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Položaj na ekranu</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="61"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
Keep trying to connect…</source>
        <translation>&lt;b&gt;Oprez:&lt;/b&gt; demon obavijesti reagira sporo.
Nastavi se povezivati …</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="70"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Nijedan demon za obavijesti nije pokrenut.
Koristit će se rezervni.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="73"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Upozorenje:&lt;/b&gt; Pokrenut je jedan strani demon za obavijesti (%1).
Ove postavke na njega ne utječu!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="131"/>
        <source>Notification demo </source>
        <translation>Demonstracija obavijesti </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="132"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>Ovo je testna obavijest.
Sve obavijesti će se sada ovdje pojaviti na LXQt-u.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Obavijesti radne površine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Osnovne postavke</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Napredne postavke</translation>
    </message>
</context>
</TS>
